@@ -6,7 +6,7 @@ use warnings;
 use DynaLoader ();
 
 use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK );
-$VERSION   = "0.47";
+$VERSION   = "0.48";
 @ISA       = qw( DynaLoader Exporter );
 @EXPORT    = qw( DDumper DTidy DDsort DPeek DDisplay DDump DHexDump
 		 DDual DGrow );
@@ -58,15 +58,13 @@ my %sk = (
 my  $_sortkeys = 1;
 our $_perltidy = 0;
 
-sub DDsort
-{
+sub DDsort {
     @_ or return;
 
     $_sortkeys = exists $sk{$_[0]} ? $sk{$_[0]} : $_[0];
     } # DDsort
 
-sub import
-{
+sub import {
     my @exp = @_;
     my @etl;
     foreach my $p (@exp) {
@@ -82,8 +80,7 @@ sub import
     __PACKAGE__->export_to_level (1, @etl);
     } # import
 
-sub DDumper
-{
+sub DDumper {
     $_perltidy and goto \&DTidy;
 
     local $Data::Dumper::Sortkeys  = $_sortkeys;
@@ -104,8 +101,7 @@ sub DDumper
     return $s;
     } # DDumper
 
-sub DTidy
-{
+sub DTidy {
     $has_perltidy or goto \&DDumper;
 
     local $Data::Dumper::Sortkeys  = $_sortkeys;
@@ -137,8 +133,7 @@ sub DTidy
 
 ### ############# DDump () ####################################################
 
-sub _DDump_ref
-{
+sub _DDump_ref {
     my (undef, $down) = (@_, 0);
 
     my $ref = ref $_[0];
@@ -164,8 +159,7 @@ sub _DDump_ref
     undef;
     } # _DDump_ref
 
-sub _DDump
-{
+sub _DDump {
     my (undef, $down, $dump, $fh) = (@_, "");
 
     if ($has_perlio and open $fh, ">", \$dump) {
@@ -181,10 +175,9 @@ sub _DDump
     return $dump;
     } # _DDump
 
-sub DDump ($;$)
-{
-    my (undef, $down) = (@_, 0);
-    my @dump = split m/[\r\n]+/, _DDump ($_[0], wantarray || $down) or return;
+sub DDump (;$$) {
+    my $down = @_ > 1 ? $_[1] : 0;
+    my @dump = split m/[\r\n]+/, _DDump (@_ ? $_[0] : $_, wantarray || $down) or return;
 
     if (wantarray) {
 	my %hash;
@@ -208,8 +201,7 @@ sub DDump ($;$)
     warn $dump;
     } # DDump
 
-sub DHexDump
-{
+sub DHexDump {
     use bytes;
     my $off = 0;
     my @out;
@@ -302,7 +294,7 @@ result is further beautified to meet my needs:
   * arrows for hashes are aligned at 16 (longer keys don't align)
   * closing braces and brackets are now correctly aligned
 
-In void context, C<DDumper ()> warn ()'s.
+In void context, C<DDumper> C<warn>'s.
 
 Example
 
@@ -371,8 +363,8 @@ These can also be passed to import:
 
 =head2 DPeek ($var)
 
-Playing with C<sv_dump ()>, I found C<Perl_sv_peek ()>, and it might be
-very useful for simple checks. If C<$var> is omitted, uses $_.
+Playing with C<sv_dump>, I found C<Perl_sv_peek>, and it might be very
+useful for simple checks. If C<$var> is omitted, uses $_.
 
 Example
 
@@ -380,7 +372,7 @@ Example
 
   PV("abc\nde\342\202\254fg"\0) [UTF8 "abc\nde\x{20ac}fg"]
 
-In void context, C<DPeek ()> prints to C<STDERR> plus a newline.
+In void context, C<DPeek> prints to C<STDERR> plus a newline.
 
 =head2 DDisplay
 
@@ -388,9 +380,9 @@ In void context, C<DPeek ()> prints to C<STDERR> plus a newline.
 
 Show the PV content of a scalar the way perl debugging would have done.
 UTF-8 detection is on, so this is effectively the same as returning the
-first part the C<DPeek ()> returns for non-UTF8 PV's or the second part
-for UTF-8 PV's. C<DDisplay ()> returns the empty string for scalars that
-no have a valid PV.
+first part the C<DPeek> returns for non-UTF8 PV's or the second part for
+UTF-8 PV's. C<DDisplay> returns the empty string for scalars that no
+have a valid PV.
 
 Example
 
@@ -398,7 +390,7 @@ Example
 
   "abc\nde\x{20ac}fg"
 
-In void context, C<DDisplay ()> uses C<warn> to display the result.
+In void context, C<DDisplay> uses C<warn> to display the result.
 
 =head2 DHexDump
 
@@ -466,13 +458,13 @@ not shrink.
 
 =head2 my $tp = triplevar ($pv, $iv, $nv)
 
-When making C<DDual ()> I wondered if it were possible to create triple-val
-scalar variables. L<Scalar::Util> already gives us C<dualvar ()>, that creates
+When making C<DDual> I wondered if it were possible to create triple-val
+scalar variables. L<Scalar::Util> already gives us C<dualvar>, that creates
 you a scalar with different numeric and string values that return different
-values in different context. Not that C<triplevar ()> would be very useful,
-compared to C<dualvar ()>, but at least this shows that it is possible.
+values in different context. Not that C<triplevar> would be very useful,
+compared to C<dualvar>, but at least this shows that it is possible.
 
-C<triplevar ()> is not exported by default.
+C<triplevar> is not exported by default.
 
 Example:
 
@@ -485,21 +477,23 @@ Example:
   SV_UNDEF
   IV(0)
 
-=head2 DDump ($var [, $dig_level])
+=head2 DDump ([$var [, $dig_level]])
 
 A very useful module when debugging is C<Devel::Peek>, but is has one big
 disadvantage: it only prints to STDERR, which is not very handy when your
 code wants to inspect variables at a low level.
 
-Perl itself has C<sv_dump ()>, which does something similar, but still
-prints to STDERR, and only one level deep.
+Perl itself has C<sv_dump>, which does something similar, but still prints
+to STDERR, and only one level deep.
 
-C<DDump ()> is an attempt to make the innards available to the script level
-with a reasonable level of compatibility. C<DDump ()> is context sensitive.
+C<DDump> is an attempt to make the innards available to the script level
+with a reasonable level of compatibility. C<DDump> is context sensitive.
 
-In void context, it behaves exactly like C<Perl_sv_dump ()>.
+In void context, it behaves exactly like C<Perl_sv_dump>.
 
-In scalar context, it returns what C<Perl_sv_dump ()> would have printed.
+In scalar context, it returns what C<Perl_sv_dump> would have printed.
+
+The default for the first argument is C<$_>.
 
 In list context, it returns a hash of the variable's properties. In this mode
 you can pass an optional second argument that determines the depth of digging.
@@ -591,7 +585,7 @@ Example
 
 =head2 DDump_IO ($io, $var [, $dig_level])
 
-A wrapper function around perl's internal C<Perl_do_sv_dump ()>, which
+A wrapper function around perl's internal C<Perl_do_sv_dump>, which
 makes C<Devel::Peek> completely superfluous.
 
 Example
@@ -661,18 +655,18 @@ Example
 
 =head1 INTERNALS
 
-C<DDump ()> uses an XS wrapper around C<Perl_sv_dump ()> where the
-STDERR is temporarily caught to a pipe. The internal XS helper functions
-are not meant for user space
+C<DDump> uses an XS wrapper around C<Perl_sv_dump> where the STDERR is
+temporarily caught to a pipe. The internal XS helper functions are not
+meant for user space
 
 =head2 DDump_XS (SV *sv)
 
-Base interface to internals for C<DDump ()>.
+Base interface to internals for C<DDump>.
 
 =head1 BUGS
 
 Windows and AIX might be using a build where not all symbols that were
-supposed to be exported in the public API are not. Perl_pv_peek () is
+supposed to be exported in the public API are not. C<Perl_pv_peek> is
 one of them.
 
 Not all types of references are supported.
@@ -691,7 +685,7 @@ H.Merijn Brand <h.m.brand@xs4all.nl>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2017 H.Merijn Brand
+Copyright (C) 2008-2018 H.Merijn Brand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
